..
    SPDX-FileCopyrightText: 2024 Alec Delaney, for Adafruit Industries
    SPDX-License-Identifier: MIT

Caching the Latest Version Weekly
=================================

.. tabs::

    .. tab:: bash

        .. literalinclude:: ../../examples/bash/weekly_cache.sh
            :language: bash

    .. tab:: powershell

        .. literalinclude:: ../../examples/powershell/weekly_cache.ps1
            :language: powershell
